package com.muyu.system.properties;

import com.muyu.web.domain.ServerConfig;
import com.muyu.web.domain.model.ServerConfigModel;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @Author: DongZeLiang
 * @date: 2024/6/10
 * @Description: 服务器配置类
 * @Version: 1.0
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class ServerConfigProperties {

    /**
     * 主机地址
     */
    private String host;
    /**
     * 端口号
     */
    private String port;
    /**
     * 负载地址
     */
    private String uri;
    /**
     * 负载请求格式化地址
     */
    private String loadReqUrl;
    /**
     * 默认MQTT地址
     */
    private String mqttAddr;
    /**
     * 默认MQTT主题
     */
    private String mqttTopic;
    /**
     * 默认MQTT交付级别
     */
    private Integer mqttQos;

    /**
     * 模型构建配置
     * @param serverConfigModel 配置模型对象
     * @return 配置对象
     */
    public static ServerConfigProperties modelToProperties(ServerConfigModel serverConfigModel) {

        return ServerConfigProperties.builder()
                .host(serverConfigModel.getHost())
                .port(serverConfigModel.getPort())
                .uri(serverConfigModel.getUri())
                .mqttAddr(serverConfigModel.getDefaultMqttAddr())
                .mqttTopic(serverConfigModel.getDefaultMqttTopic())
                .mqttQos(serverConfigModel.getDefaultMqttQos())
                .loadReqUrl(
                        String.format(
                                "http://%s:%s%s",
                                serverConfigModel.getHost(),
                                serverConfigModel.getPort(),
                                serverConfigModel.getUri().startsWith("/") ? serverConfigModel.getUri() : "/" + serverConfigModel.getUri()
                        )
                )
                .build();
    }
    /**
     * 模型构建配置
     * @param serverConfig 配置对象
     * @return 配置对象
     */
    public static ServerConfigProperties configToProperties(ServerConfig serverConfig ) {

        return ServerConfigProperties.builder()
                .host(serverConfig.getHost())
                .port(serverConfig.getPort())
                .uri(serverConfig.getUri())
                .mqttAddr(serverConfig.getDefaultMqttAddr())
                .mqttTopic(serverConfig.getDefaultMqttTopic())
                .mqttQos(serverConfig.getDefaultMqttQos())
                .loadReqUrl(
                        String.format(
                                "http://%s:%s%s",
                                serverConfig.getHost(),
                                serverConfig.getPort(),
                                serverConfig.getUri().startsWith("/") ? serverConfig.getUri() : "/" + serverConfig.getUri()
                        )
                )
                .build();
    }

}
