package com.muyu.web.domain;

import com.baomidou.mybatisplus.annotation.*;
import com.muyu.web.domain.model.ServerConfigModel;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.function.Supplier;

/**
 * @Author: DongZeLiang
 * @date: 2024/6/10
 * @Description: 服务器配置
 * @Version: 1.0
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@TableName(value = "server_config")
public class ServerConfig {

    /**
     * 主键
     */
    @TableId(
            value = "id",
            type = IdType.AUTO
    )
    private Long id;

    /**
     * 租户ID
     */
    @TableField(value = "tenant_id", fill = FieldFill.INSERT)
    private String tenantId;

    /**
     * 主机地址
     */
    private String host;
    /**
     * 端口号
     */
    private String port;
    /**
     * 负载地址
     */
    private String uri;
    /**
     * 默认MQTT地址
     */
    private String defaultMqttAddr;
    /**
     * 默认MQTT主题
     */
    private String defaultMqttTopic;
    /**
     * 默认MQTT交付级别
     */
    private Integer defaultMqttQos;

    public static ServerConfig modeBuild (ServerConfigModel serverConfigModel, Supplier<Long> idKey) {
        return builder()
                .id(idKey.get())
                .host(serverConfigModel.getHost())
                .port(serverConfigModel.getPort())
                .uri(serverConfigModel.getUri())
                .defaultMqttAddr(serverConfigModel.getDefaultMqttAddr())
                .defaultMqttTopic(serverConfigModel.getDefaultMqttTopic())
                .defaultMqttQos(serverConfigModel.getDefaultMqttQos())
                .build();
    }
}
